@@ -13,8 +13,8 @@ surfaces such as many mathematical functions.
 In most cases, hillshading is used purely for visual purposes, and *dx*/*dy*
 can be safely ignored. In that case, you can tweak *vert_exag* (vertical
 exaggeration) by trial and error to give the desired visual effect. However,
-this example demonstrates how to use the *dx* and *dy* kwargs to ensure that
-the *vert_exag* parameter is the true vertical exaggeration.
+this example demonstrates how to use the *dx* and *dy* keyword arguments to
+ensure that the *vert_exag* parameter is the true vertical exaggeration.
 """
 import numpy as np
 import matplotlib.pyplot as plt
@@ -24,7 +24,7 @@ from matplotlib.colors import LightSource
 
 dem = get_sample_data('jacksboro_fault_dem.npz', np_load=True)
 z = dem['elevation']
-#-- Optional dx and dy for accurate vertical exaggeration ---------------------
+# -- Optional dx and dy for accurate vertical exaggeration --------------------
 # If you need topographically accurate vertical exaggeration, or you don't want
 # to guess at what *vert_exag* should be, you'll need to specify the cellsize
 # of the grid (i.e. the *dx* and *dy* parameters).  Otherwise, any *vert_exag*
@@ -36,7 +36,7 @@ z = dem['elevation']
 dx, dy = dem['dx'], dem['dy']
 dy = 111200 * dy
 dx = 111200 * dx * np.cos(np.radians(dem['ymin']))
-#------------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 # Shade from the northwest, with the sun 45 degrees from horizontal
 ls = LightSource(azdeg=315, altdeg=45)
@@ -58,7 +58,7 @@ for col, ve in zip(axs.T, [0.1, 1, 10]):
 
 # Label rows and columns
 for ax, ve in zip(axs[0], [0.1, 1, 10]):
-    ax.set_title('{0}'.format(ve), size=18)
+    ax.set_title(f'{ve}', size=18)
 for ax, mode in zip(axs[:, 0], ['Hillshade', 'hsv', 'overlay', 'soft']):
     ax.set_ylabel(mode, size=18)
 
